@@ -1,4 +1,5 @@
 mod rb_any;
+mod rb_compare;
 mod rb_ref;
 mod rb_hash;
 mod rb_float;
@@ -9,13 +10,16 @@ mod deserialize;
 mod serialize;
 pub mod dump;
 
+#[cfg(feature = "json")]
+mod rb_json;
+
 // This is so we can safely define the ref type in the parent module
-pub use super::RcType;
+pub use super::{RcType, rc_get_ptr};
 
 pub use rb_any::RbAny;
-pub use rb_float::RFloat32;
+pub use rb_float::RbFloat;
 pub use rb_hash::RbHash;
-pub use rb_misc::{RbClass, RbFields, RbSymbol};
+pub use rb_misc::{RbClass, RbFields, RbSymbol, RbUserData};
 pub use rb_ref::RbRef;
 pub use rb_object::RbObject;
 pub use serialize::to_writer;
